@@ -51,16 +51,24 @@ class Francophone(Payment):
 
         feature_name = "Initiate-Francophone-mobile-money-charge"
         endpoint = self._baseUrl + self._endpointMap["account"]["charge"]
+
         # It is faster to add boilerplate than to check if each one is present
         accountDetails.update({"payment_type": "mobilemoneyfrancophone", "is_mobile_money_franco":"1"})
         
         # If transaction reference is not set 
         if not ("txRef" in accountDetails):
             accountDetails.update({"txRef": generateTransactionReference()})
+
         # If order reference is not set
         if not ("orderRef" in accountDetails):
             accountDetails.update({"orderRef": generateTransactionReference()})
+
         # Checking for required account components
         # requiredParameters = ["amount", "email", "phonenumber", "IP", "redirect_url"]
         requiredParameters = ["amount"]
         return super(Francophone, self).charge(feature_name, accountDetails, requiredParameters, endpoint)
+
+    def refund(self, flwRef, amount):
+        feature_name = "Francophone-charge-refund"
+        endpoint = self._baseUrl + self._endpointMap["refund"]
+        return super(Francophone, self).refund(feature_name, flwRef, amount)
